@@ -18,66 +18,25 @@ function(text.var) {
 ## multigsub - A wrapper for \code{\link[base]{gsub}} that takes a vector 
 ## of search terms and a vector or single value of replacements.
 .mgsub <-
-function(pattern, replacement = NULL, text.var, leadspace = FALSE, 
-    trailspace = FALSE, fixed = TRUE, trim = TRUE, order.pattern = fixed, ...){
+function (pattern, replacement, text.var, fixed = TRUE, trim = TRUE, 
+    order.pattern = fixed, ...) {
 
-    if (leadspace | trailspace) {
-        replacement <- spaste(replacement, trailing = trailspace, 
-            leading = leadspace)
-    }
-
-    ## replaces the larger n character words first
     if (fixed && order.pattern) {
-        if (!is.null(replacement) && length(replacement) > 1) {
-            replacement <- replacement[rev(order(nchar(pattern)))]
-        }
-        pattern <- pattern[rev(order(nchar(pattern)))]
+        ord <- rev(order(nchar(pattern)))
+        pattern <- pattern[ord]
+        if (length(replacement) != 1) replacement <- replacement[ord]
+    }
+    if (length(replacement) == 1) replacement <- rep(replacement, length(pattern))
+   
+    for (i in seq_along(pattern)){
+        text.var <- gsub(pattern[i], replacement[i], text.var, fixed = fixed, ...)
     }
 
-    key <- data.frame(pat=pattern, rep=replacement, 
-        stringsAsFactors = FALSE)
-
-    msubs <-function(K, x, trim, ...){
-        sapply(seq_len(nrow(K)), function(i){
-                x <<- gsub(K[i, 1], K[i, 2], x, fixed = fixed, ...)
-            }
-        )
-        if (trim) x <- gsub(" +", " ", x)
-        return(x)
-    }
-
-    if (trim) {
-        x <- Trim(msubs(K=key, x=text.var, trim = trim, ...))
-    } else {    
-        x <- msubs(K=key, x=text.var, trim = trim, ...)
-    }
-
-    return(x)
+    if (trim) text.var <- gsub("\\s+", " ", gsub("^\\s+|\\s+$", "", text.var, 
+        perl=TRUE), perl=TRUE)
+    text.var
 }
 
-## Add Leading/Trailing Spaces
-## 
-## Adds trailing and/or leading spaces to a vector of terms.
-spaste <- 
-function(terms, trailing = TRUE, leading = TRUE){
-    if (leading) {
-        s1 <- " "
-    } else {
-        s1 <- ""
-    }
-    if (trailing) {
-        s2 <- " "
-    } else {
-        s2 <- ""
-    }
-    pas <- function(x) paste0(s1, x, s2)
-    if (is.list(terms)) {
-        z <- lapply(terms, pas)
-    } else {
-        z <- pas(terms)
-    }
-    return(z)
-}
 
 
 
@@ -143,32 +102,23 @@ hijack <- function(FUN, ...){
     invisible(lapply(seq_along(args), function(i) {
         formals(.FUN)[[names(args)[i]]] <<- args[[i]]
     }))
-	
+
     .FUN
 }
 
 ## Function to visualize regex dictionaries
 examine_regex <- function(dictionary = qdapRegex::regex_usa){
-
     lapply(seq_along(dictionary), function(i){
-    
         message(sprintf("\nHere's the regex for `%s`:\n\n  %s", names(dictionary)[i], 
             dictionary[[i]]), "\n\nDo you want to view it?")
         ans <- menu(c("Yes", "No"))
-        if (ans == "2") {
-            return(NULL)
-        } else {
-            open <- TRUE
-            if (grepl("\\(\\?\\<[=!]", dictionary[[i]], perl=TRUE)) {
-                warning(immediate. = TRUE, paste("Pattern contains a Lookbehind and is not",
-                    "viewable to the Java based `www.regexper.com`\n\n",
-                    "Setting `open = FALSE`"))
-                flush.console()
-                Sys.sleep(1)
-                open <- FALSE
-            } 
-            explain(dictionary[[i]], open=open)
-        }
-    
+        if (ans == "2") return(NULL) 
+        open <- TRUE
+        if (grepl("\\(\\?\\<[=!]", dictionary[[i]], perl=TRUE)) {
+            warning(immediate. = TRUE, paste("Pattern contains a Lookbehind and is not",
+                "viewable to the Java based `www.regexper.com`\n\n", "Setting `open = FALSE`"))
+            flush.console(); Sys.sleep(1); open <- FALSE
+        } 
+        explain(dictionary[[i]], open=open)
     })
 }
